@@ -2,18 +2,17 @@
 
 -- Copyright (C) 2012 John Millikin <john@john-millikin.com>
 --
--- This program is free software: you can redistribute it and/or modify
--- it under the terms of the GNU General Public License as published by
--- the Free Software Foundation, either version 3 of the License, or
--- any later version.
+-- Licensed under the Apache License, Version 2.0 (the "License");
+-- you may not use this file except in compliance with the License.
+-- You may obtain a copy of the License at
 --
--- This program is distributed in the hope that it will be useful,
--- but WITHOUT ANY WARRANTY; without even the implied warranty of
--- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
--- GNU General Public License for more details.
+--     http://www.apache.org/licenses/LICENSE-2.0
 --
--- You should have received a copy of the GNU General Public License
--- along with this program.  If not, see <http://www.gnu.org/licenses/>.
+-- Unless required by applicable law or agreed to in writing, software
+-- distributed under the License is distributed on an "AS IS" BASIS,
+-- WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+-- See the License for the specific language governing permissions and
+-- limitations under the License.
 
 module DBusTests.Integration (test_Integration) where
 
@@ -59,11 +58,18 @@ test_Client = withDaemon "client" $ \addr -> do
     clientB <- connect addr
 
     export clientA "/"
-        [ method "com.example.Echo" "Echo" (signature_ [TypeString]) (signature_ []) (
-            \msg -> if map variantType (methodCallBody msg) == [TypeString]
-                then return (replyReturn (methodCallBody msg))
-                else return (replyError "com.example.Error" [toVariant ("bad body: " ++ show (methodCallBody msg))]))
-        ]
+           defaultInterface
+           { interfaceName = "com.example.Echo"
+           , interfaceMethods =
+               [ Method "Echo" (signature_ [TypeString]) (signature_ []) (
+                 \msg -> if map variantType (methodCallBody msg) == [TypeString]
+                         then return (ReplyReturn (methodCallBody msg))
+                         else
+                           return $ ReplyError
+                                    "com.example.Error"
+                                    [toVariant ("bad body: " ++ show (methodCallBody msg))])
+               ]
+           }
 
     -- TODO: get bus address of clientA with a function
     let busAddrA = ":1.0"
